embassy-stm32

Crates

git

Versions

stm32h757ii-cm7

Flavors

WWDG1

Struct WWDG1 

pub struct WWDG1 { /* private fields */ }
WWDG1 peripheral

Implementations

Source

impl WWDG1

pub const unsafe fn steal() -> Peri<'static, Self>

Unsafely create an instance of this peripheral out of thin air.

Safety

You must ensure that you’re only using one instance of this type at a time.